.. image:: https://github.com/zopefoundation/Zope/actions/workflows/tests.yml/badge.svg
        :target: https://github.com/zopefoundation/Zope/actions/workflows/tests.yml

.. image:: https://coveralls.io/repos/github/zopefoundation/Zope/badge.svg?branch=master
        :target: https://coveralls.io/github/zopefoundation/Zope?branch=master

.. image:: https://readthedocs.org/projects/zope/badge/?version=latest
        :target: https://zope.readthedocs.org/en/latest/
        :alt: Documentation Status

.. image:: https://img.shields.io/pypi/v/Zope.svg
        :target: https://pypi.org/project/Zope/
        :alt: Current version on PyPI

.. image:: https://img.shields.io/pypi/pyversions/Zope.svg
        :target: https://pypi.org/project/Zope/
        :alt: Supported Python versions

.. |nbsp| unicode:: 0xA0 
        :trim:

|nbsp|

.. image:: https://zopefoundation.github.io/Zope/artwork/Zope.svg
        :alt: Zope logo
        :width: 300px

**Zope is an open-source web application server.**

This document provides some general information about Zope and provides
links to other documents. The full documentation can be found at
https://zope.readthedocs.io.


Installation
============

Please visit the installation documentation at
https://zope.readthedocs.io/en/latest/INSTALL.html for detailed installation
guidance.


License
=======

Zope is licensed under the OSI-approved `Zope Public License` (ZPL), version
2.1. The full license text is included in ``LICENSE.txt``.


Bug tracker
===========

Bugs reports should be made through the Zope bugtracker at
https://github.com/zopefoundation/Zope/issues.  A bug report should
contain detailed information about how to reproduce the bug.
